============
Installation
============

Install scopus from PyPI:

.. code-block:: console

    $ pip install scopus

or directly from the GitHub repository (may be unstable):

.. code-block:: console

    $ pip install git+git://github.com/scopus-api/scopus

To access the Scopus database using `scopus`, you need an API key which you can get from http://dev.elsevier.com/myapikey.html after registration.  Additionally, you need to be in your institution's network or you need to have an InstToken.  If you use InstToken please follow the steps explained in :doc:`Configuration </configuration>`, otherwise simply use `scopus` which will prompt you for your API Key when necessary.

See extended description and examples in the :doc:`Examples </examples>` section.
